@@ -20,7 +20,8 @@ SECTIONS = (LIFECYCLE, CONFIGURE, LIFECYCLE_SHORTNAME,
             'tosca.interfaces.relationship.Configure',
             'Standard', 'Configure')
 
-INTERFACEVALUE = (IMPLEMENTATION, INPUTS) = ('implementation', 'inputs')
+INTERFACEVALUE = (IMPLEMENTATION, INPUTS, OUTPUTS) = \
+    ('implementation', 'inputs', 'outputs')
 
 INTERFACE_DEF_RESERVED_WORDS = ['type', 'inputs', 'derived_from', 'version',
                                 'description']
@@ -39,6 +40,7 @@ class InterfacesDef(StatefulEntityType):
         self.value = value
         self.implementation = None
         self.inputs = None
+        self.outputs = None
         self.defs = {}
         if interfacename == LIFECYCLE_SHORTNAME:
             self.interfacetype = LIFECYCLE
@@ -71,6 +73,8 @@ class InterfacesDef(StatefulEntityType):
                         self.implementation = j
                     elif i == INPUTS:
                         self.inputs = j
+                    elif i == OUTPUTS:
+                        self.outputs = j
                     else:
                         what = ('"interfaces" of template "%s"' %
                                 self.node_template.name)
